"Sqlite3 binding for PySimpleGUI"

from .pysimplesql import *
from update_checker import UpdateChecker

__name__ = "pysimplesql"
__version__ = "0.1.1"
__keywords__ = ["SQL", "sqlite", "sqlite3", "database", "front-end", "access", "libre office", "GUI", "PySimpleGUI"]
__author__ = "Jonathan Decker"
__author_email__ = "pysimplesql@gmail.com"
__url__ = "https://github.com/PySimpleSQL/pysimplesql"
__platforms__ = "ALL"
__classifiers__ = [
        "Programming Language :: Python",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Topic :: Database :: Front-Ends",
        "Operating System :: OS Independent",
]
__requires__ =  ['PySimpleGUI','update_checker']
__extra_requires__ = {
}

# -------------------------
# Check for package updates
# -------------------------
checker = UpdateChecker()
result = checker.check('pysimplesql', __version__)
if result is not None:
    release_date=f'(released {result.release_date}) ' if result.release_date is not None else ''
    print(f'***** pysimplesql update from {__version__} to {result.available_version} {release_date} available! Be sure to run pip3 install pysimplesql --upgrade *****')



"Setup script for pysimplesql"

from setuptools import setup, find_packages
import os

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

def main():
    "Executes setup when this script is the top-level"
    import pysimplesql as app

    setup(
        name=app.__name__,
        version=app.__version__,
        author=app.__author__,
        author_email=app.__author_email__,
        description=app.__doc__,
        long_description=read('README.md'),
        long_description_content_type="text/markdown",
        keywords=app.__keywords__,
        url=app.__url__,
        download_url=f"https://github.com/PySimpleSQL/pysimplesql/archive/refs/tags/v{app.__version__}.tar.gz",
        packages=find_packages(),
        install_requires=app.__requires__,
        extras_require=app.__extra_requires__,
        classifiers=app.__classifiers__,
        license=[
            c.rsplit('::', 1)[1].strip()
            for c in app.__classifiers__
            if c.startswith('License ::')
        ][0],
        include_package_data=True,
        platforms=app.__platforms__,
    )

if __name__ == '__main__':
    main()

